@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::Rosetta::Interface; # module
-    use version 0.74; our $VERSION = qv('0.11.0');
+    use version 0.74; our $VERSION = qv('0.11.1');
     # Note: This given version applies to all of this file's packages.
 
     use Carp;
@@ -80,7 +80,7 @@ sub new_machine {
 ###########################################################################
 
 { package Muldis::Rosetta::Interface::Machine; # role
-    use Moose::Role;
+    use Moose::Role 0.56;
 
     requires 'new_process';
 
@@ -90,7 +90,7 @@ sub new_machine {
 ###########################################################################
 
 { package Muldis::Rosetta::Interface::Process; # role
-    use Moose::Role;
+    use Moose::Role 0.56;
 
     requires 'assoc_machine';
     requires 'pt_command_lang';
@@ -113,7 +113,7 @@ sub new_machine {
 ###########################################################################
 
 { package Muldis::Rosetta::Interface::Value; # role
-    use Moose::Role;
+    use Moose::Role 0.56;
 
     requires 'assoc_process';
     requires 'pt_source_code';
@@ -138,7 +138,7 @@ Common public API for Muldis Rosetta Engines
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Interface version 0.11.0 for Perl
+This document describes Muldis::Rosetta::Interface version 0.11.1 for Perl
 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -497,7 +497,7 @@ Perl 5.x.y that is at least 5.10.0, and are also on CPAN for separate
 installation by users of earlier Perl versions: L<version>.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<Moose::Role-0.55|Moose::Role>.
+L<Moose::Role-0.56|Moose::Role>.
 
 =head1 INCOMPATIBILITIES
 
